# djandock

A Python script to initialize a Django project with a setup virtual environment and docker and PostgreSQL

# Usage

```Shell
$ djandock [name] -r [Git repo link]
```

1. Creates a virtual environment
2. Creates a Django project
3. Wraps the project in Docker
4. Initializes the Git repository
